@@ -61,6 +61,9 @@ from pymongo.errors import (AutoReconnect,
                             InvalidURI,
                             OperationFailure)
 from pymongo.member import Member
+from pymongo.read_preferences import ReadPreference
+
+
 EMPTY = b("")
 
 
@@ -1050,7 +1053,7 @@ class MongoClient(common.BaseObject):
         # for some errors.
         if "errObjects" in result:
             for errobj in result["errObjects"]:
-                if errobj["err"] == error_msg:
+                if errobj.get("err") == error_msg:
                     details = errobj
                     break
 
@@ -1337,13 +1340,15 @@ class MongoClient(common.BaseObject):
     def server_info(self):
         """Get information about the MongoDB server we're connected to.
         """
-        return self.admin.command("buildinfo")
+        return self.admin.command("buildinfo",
+                                  read_preference=ReadPreference.PRIMARY)
 
     def database_names(self):
         """Get a list of the names of all databases on the connected server.
         """
         return [db["name"] for db in
-                self.admin.command("listDatabases")["databases"]]
+                self.admin.command("listDatabases",
+                    read_preference=ReadPreference.PRIMARY)["databases"]]
 
     def drop_database(self, name_or_database):
         """Drop a database.
@@ -1365,7 +1370,8 @@ class MongoClient(common.BaseObject):
                             "%s or Database" % (basestring.__name__,))
 
         self._purge_index(name)
-        self[name].command("dropDatabase")
+        self[name].command("dropDatabase",
+                           read_preference=ReadPreference.PRIMARY)
 
     def copy_database(self, from_name, to_name,
                       from_host=None, username=None, password=None):
@@ -1413,12 +1419,15 @@ class MongoClient(common.BaseObject):
 
             if username is not None:
                 nonce = self.admin.command("copydbgetnonce",
-                                           fromhost=from_host)["nonce"]
+                    read_preference=ReadPreference.PRIMARY,
+                    fromhost=from_host)["nonce"]
                 command["username"] = username
                 command["nonce"] = nonce
                 command["key"] = auth._auth_key(nonce, username, password)
 
-            return self.admin.command("copydb", **command)
+            return self.admin.command("copydb",
+                                      read_preference=ReadPreference.PRIMARY,
+                                      **command)
         finally:
             self.end_request()
 
@@ -1467,7 +1476,8 @@ class MongoClient(common.BaseObject):
 
         .. versionadded:: 2.0
         """
-        self.admin.command("fsync", **kwargs)
+        self.admin.command("fsync",
+                           read_preference=ReadPreference.PRIMARY, **kwargs)
 
     def unlock(self):
         """Unlock a previously locked server.
