@@ -1,4 +1,4 @@
-# Copyright 2009-2012 10gen, Inc.
+# Copyright 2009-2014 MongoDB, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -28,10 +28,6 @@ from bson.son import SON
 
 
 class TestSON(unittest.TestCase):
-
-    def setUp(self):
-        pass
-
     def test_ordered_dict(self):
         a1 = SON()
         a1["hello"] = "world"
